@@ -4,6 +4,7 @@ from __future__ import absolute_import, print_function
 import json
 import base64
 from suanpan.g import g
+from suanpan.log import logger
 from suanpan.base import Context
 from suanpan.stream import stream
 from suanpan.arguments import suanpanTypes
@@ -46,6 +47,7 @@ class APP:
         self.afterInitFunc = func if func else self.afterInitFunc
 
     def start(self):
+        logger.info("Start Running...")
         self.paramContext = self.loadParams(g)
         if self.afterInitFunc:
             self.afterInitFunc(Context(args=self.paramContext))
@@ -55,6 +57,7 @@ class APP:
             result = self.func(context)
             if result is not None:
                 self.send(result, context)
+            logger.debug("Finshed, Waiting for Next Round...")
 
     def addArguments(self, configs):
         arguments = {}
@@ -65,6 +68,7 @@ class APP:
         return arguments
 
     def loadParams(self, context):
+        logger.debug("Loading Param Arguments:")
         params = {}
         for k, v in context.items():
             if k in self.paramArgs.keys():
@@ -72,6 +76,7 @@ class APP:
         return params
 
     def loadInputs(self, context):
+        logger.debug("Loading Input Arguments:")
         params = {}
         for k, v in context.items():
             if k.startswith("in") and k[-1].isdigit():
@@ -80,6 +85,7 @@ class APP:
         return params
 
     def saveOutputs(self, context):
+        logger.debug("Saving Output Arguments:")
         params = {}
         for k, v in context.items():
             if k.startswith("out") and k[-1].isdigit():
@@ -108,6 +114,7 @@ class APP:
     def send(self, result, context):
         result = self.formatOutput(result)
         result = self.saveOutputs(result)
+        logger.debug("Sending Result to Next Nodes...")
         stream.sendMessage(result, context)
 
     def contextGen(self):
